import { Component, OnInit, ViewChild, ElementRef, AfterViewInit, OnDestroy } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as echarts from 'echarts';

@Component({
  selector: 'app-page-interview',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './page-interview.html',
  styleUrl: './page-interview.scss'
})
export class PageInterview implements OnInit, AfterViewInit, OnDestroy {
  // 倒计时相关属性
  remainingTime: string = '30:00';
  remainingMinutes: number = 30;
  remainingSeconds: number = 0;
  timerInterval: any;

  // 其他现有属性保持不变
  isAnalyzing = false;
  showSubmitButton = false;
  userAnswer = '';
  
  avatarImages = {
    default: 'data:image/svg+xml;base64,...',
    speaking: 'data:image/svg+xml;base64,...',
  };

  questions = [
    "欢迎参加本次AI面试,我是您的面试官AI助手。",
    "首先，请简单介绍一下您自己。",
    "您在过去工作中遇到的最大技术挑战是什么？您是如何解决的？",
    "请描述一个您与团队意见不合时，您是如何处理的案例。"
  ];
  
  currentQuestionIndex = 0;
  currentQuestion = this.questions[0];
  showQuestionCard = false;
  progress = 30;
  
  messages: {sender: 'ai' | 'user', text: string}[] = [];
  
  isListening = false;
  isSpeaking = false;
  
  avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f913.svg";
  expressionText = "正在聆听您的回答...";
  
  showRadarChart = false;
  metrics = {
    expressiveness: 82,
    professionalism: 65,
    relevance: 73
  };
  
  presetAnswers = [
    "我是张伟,有5年Java开发经验,擅长分布式系统设计。",
    "我们曾遇到高并发下的数据库瓶颈,我通过引入Redis缓存和分库分表解决了问题。",
    "有一次在技术方案选择上，我通过数据对比和原型验证说服了团队采用我的方案。"
  ];
  
  @ViewChild('dialogContainer') dialogContainer!: ElementRef;
  private radarChart: any;

  ngOnInit(): void {
    this.initConversation();
    this.startCountdown(); // 启动倒计时
  }
  
  ngAfterViewInit(): void {
    this.initRadarChart();
  }
  
  ngOnDestroy(): void {
    if (this.timerInterval) {
      clearInterval(this.timerInterval);
    }
  }

  // 倒计时相关方法
  private startCountdown() {
    this.updateTimeDisplay();
    
    this.timerInterval = setInterval(() => {
      if (this.remainingSeconds > 0) {
        this.remainingSeconds--;
      } else {
        if (this.remainingMinutes > 0) {
          this.remainingMinutes--;
          this.remainingSeconds = 59;
        } else {
          clearInterval(this.timerInterval);
          this.handleTimeUp();
        }
      }
      this.updateTimeDisplay();
    }, 1000);
  }

  private updateTimeDisplay() {
    const mins = this.remainingMinutes.toString().padStart(2, '0');
    const secs = this.remainingSeconds.toString().padStart(2, '0');
    this.remainingTime = `${mins}:${secs}`;
  }

  private handleTimeUp() {
    this.addAIMessage("面试时间已结束，系统将自动提交您的回答");
    this.submitAnswer();
  }

  // 其他现有方法保持不变
  initConversation(): void {
    this.addAIMessage(this.questions[0]);
    setTimeout(() => {
      this.askQuestion(1);
    }, 1500);
  }
  
  askQuestion(index: number): void {
    if (index >= this.questions.length) return;
    
    this.currentQuestionIndex = index;
    this.currentQuestion = this.questions[index];
    this.addAIMessage(this.currentQuestion);
    this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f4ac.svg";
    this.expressionText = "等待您的回答...";
  }
  
  addAIMessage(text: string): void {
    this.messages.push({ sender: 'ai', text: text });
    setTimeout(() => {
      this.dialogContainer.nativeElement.scrollTop = this.dialogContainer.nativeElement.scrollHeight;
    }, 0);
    this.speakText(text);
  }
  
  addUserMessage(text: string): void {
    this.messages.push({ sender: 'user', text: text });
    setTimeout(() => {
      this.dialogContainer.nativeElement.scrollTop = this.dialogContainer.nativeElement.scrollHeight;
    }, 0);
  }
  
  speakText(text: string): void {
    if (this.isSpeaking) return;
    
    this.isSpeaking = true;
    this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f5e3.svg";
    this.expressionText = "正在播报问题...";
    
    const utterance = new SpeechSynthesisUtterance(text);
    utterance.lang = 'zh-CN';
    utterance.rate = 0.9;
    utterance.pitch = 1;
    
    utterance.onend = () => {
      this.isSpeaking = false;
      this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f4ac.svg";
      this.expressionText = "等待您的回答...";
    };
    
    speechSynthesis.speak(utterance);
  }
  
  startVoiceInput(): void {
    this.isListening = true;
    this.expressionText = "正在聆听您的回答...";
  }
  
  stopVoiceInput(): void {
    this.isListening = false;
    this.userAnswer = this.presetAnswers[this.currentQuestionIndex - 1] || "这是我的回答...";
    this.showSubmitButton = true;
    this.avatarImage = this.avatarImages.default;
    this.expressionText = "请确认您的回答";
  }
  
  submitAnswer(): void {
    this.showSubmitButton = false;
    this.addUserMessage(this.userAnswer);
    this.isAnalyzing = true;
    this.avatarImage = this.avatarImages.default;
    this.expressionText = "正在分析您的回答...";
    
    setTimeout(() => {
      this.isAnalyzing = false;
      if (this.currentQuestionIndex < this.questions.length - 1) {
        this.askQuestion(this.currentQuestionIndex + 1);
      } else {
        this.addAIMessage("感谢您的回答，面试即将结束，正在生成最终报告...");
        this.avatarImage = this.avatarImages.speaking;
        this.expressionText = "生成最终评估中...";
      }
    }, 2000);
  }
  
  playQuestion(): void {
    if (!this.isSpeaking) {
      this.speakText(this.questions[this.currentQuestionIndex]);
    }
  }
  
  toggleRadarChart(): void {
    this.showRadarChart = !this.showRadarChart;
    if (this.showRadarChart) {
      setTimeout(() => {
        this.initRadarChart();
      }, 0);
    }
  }
  
  initRadarChart(): void {
    if (!this.showRadarChart) return;
    
    const chartDom = document.getElementById('radarChart');
    if (!chartDom) return;
    
    if (this.radarChart) {
      this.radarChart.dispose();
    }
    
    this.radarChart = echarts.init(chartDom);
    
    const option = {
      backgroundColor: 'transparent',
      tooltip: {},
      radar: {
        shape: 'circle',
        indicator: [
          { name: '表达能力', max: 100 },
          { name: '专业深度', max: 100 },
          { name: '岗位匹配', max: 100 },
          { name: '应变能力', max: 100 },
          { name: '沟通技巧', max: 100 },
          { name: '知识广度', max: 100 }
        ],
        radius: '65%',
        axisName: {
          color: '#4A5568'
        },
        splitArea: {
          areaStyle: {
            color: ['rgba(42, 92, 170, 0.1)']
          }
        },
        axisLine: {
          lineStyle: {
            color: 'rgba(42, 92, 170, 0.3)'
          }
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(42, 92, 170, 0.3)'
          }
        }
      },
      series: [{
        type: 'radar',
        data: [
          {
            value: [82, 65, 73, 68, 75, 60],
            name: '当前表现',
            areaStyle: {
              color: 'rgba(42, 92, 170, 0.4)'
            },
            lineStyle: {
              width: 2,
              color: 'rgba(42, 92, 170, 0.8)'
            },
            itemStyle: {
              color: '#2A5CAA'
            }
          },
          {
            value: [70, 80, 85, 75, 65, 70],
            name: '岗位要求',
            areaStyle: {
              color: 'rgba(255, 107, 53, 0.2)'
            },
            lineStyle: {
              width: 2,
              color: 'rgba(255, 107, 53, 0.8)'
            },
            itemStyle: {
              color: '#FF6B35'
            }
          }
        ]
      }]
    };
    
    this.radarChart.setOption(option);
    
    window.addEventListener('resize', () => {
      this.radarChart?.resize();
    });
  }
}